﻿#Region " Imports "
Imports System
Imports System.Collections.Generic
Imports System.ComponentModel
Imports System.Data
Imports System.Diagnostics
#End Region

Public Class Database

#Region " Constants "
    Private Const DATABASE_ROW_COUNT As Integer = 200
#End Region

#Region " Declarations "
    Private _selectedValue As String
    Private _recordCount As Integer
#End Region

#Region " Properties "
    Public Property SelectedValue() As String
        Get
            Return _selectedValue
        End Get
        Set(ByVal value As String)
            _selectedValue = value
        End Set
    End Property

    Public ReadOnly Property RecordCount() As Integer
        Get
            Return CInt(_recordCount)
        End Get
    End Property
#End Region

#Region " Methods "
    Public Function BuildDataTable(name As String) As DataTable
        Dim table As System.Data.DataTable = New DataTable(name)
        BuildDataColumns(table)
        Dim row As DataRow
        Dim iView As Integer = 0

        For i As Integer = 1 To DATABASE_ROW_COUNT
            row = table.NewRow()
            row(FieldName.HiddenRef) = "SR000" & i
            row(FieldName.HiddenStatus) = "ACTIVE"
            row(FieldName.HiddenUncontrolledProfile) = "H"
            row(FieldName.HiddenCurrentProfile) = "H"
            row(FieldName.HiddenControlledProfile) = "M"
            For Each column As DataColumn In table.Columns
                Select Case column.ColumnName
                    Case FieldName.Alert
                        row(FieldName.Alert) = 2
                    Case FieldName.Completed
                        row(FieldName.Completed) = True
                    Case FieldName.Ref
                        row(FieldName.Ref) = "SR000" & i
                    Case FieldName.Details
                        row(FieldName.Details) = "Failure to become a Core. [" & i & "]"
                    Case FieldName.Status
                        row(FieldName.Status) = "Average"
                    Case FieldName.CostToDate
                        row(FieldName.CostToDate) = 2.0
                    Case FieldName.CurrentProfile
                        row(FieldName.CurrentProfile) = "High"
                    Case FieldName.CurrentRating
                        row(FieldName.CurrentRating) = 12
                    Case FieldName.AssignedTo
                        row(FieldName.AssignedTo) = "Bob" & i
                    Case FieldName.Category
                        row(FieldName.Category) = "Financial [" & i & "]"
                    Case FieldName.RevPeriod
                        row(FieldName.RevPeriod) = "3"
                    Case FieldName.BusUnit
                        row(FieldName.BusUnit) = "Stategic Department [" & i & "]"
                    Case FieldName.NatureofRecord
                        row(FieldName.NatureofRecord) = " Blah blah blah blah [" & i & "]"
                    Case FieldName.UncontrolledProfile
                        row(FieldName.UncontrolledProfile) = "High"
                    Case FieldName.UncontrolledRating
                        row(FieldName.UncontrolledRating) = 16
                    Case FieldName.EstimatedCost
                        row(FieldName.EstimatedCost) = 5.0
                    Case FieldName.ControlledProfile
                        row(FieldName.ControlledProfile) = "Medium"
                    Case FieldName.ControlledRating
                        row(FieldName.ControlledRating) = 8
                End Select
            Next
            table.Rows.Add(row)
        Next
        _recordCount = table.Rows.Count

        Return table

    End Function

    Private Sub BuildDataColumns(dttable As DataTable)
        Dim column As DataColumn
        Dim sColumns() As String = Nothing
        column = New DataColumn()
        column.DataType = System.Type.GetType("System.String")
        column.ColumnName = FieldName.HiddenRef
        column.Caption = FieldName.HiddenRef
        dttable.Columns.Add(column)
        dttable.PrimaryKey = New DataColumn() {column} '<<<<<<<<<< PK <<<<<<<

        column = New DataColumn()
        column.DataType = System.Type.GetType("System.String")
        column.ColumnName = FieldName.HiddenStatus
        column.Caption = FieldName.HiddenStatus
        dttable.Columns.Add(column)

        column = New DataColumn()
        column.DataType = System.Type.GetType("System.String")
        column.ColumnName = FieldName.HiddenUncontrolledProfile
        column.Caption = FieldName.HiddenUncontrolledProfile
        dttable.Columns.Add(column)

        column = New DataColumn()
        column.DataType = System.Type.GetType("System.String")
        column.ColumnName = FieldName.HiddenCurrentProfile
        column.Caption = FieldName.HiddenCurrentProfile
        dttable.Columns.Add(column)

        column = New DataColumn()
        column.DataType = System.Type.GetType("System.String")
        column.ColumnName = FieldName.HiddenControlledProfile
        column.Caption = FieldName.HiddenControlledProfile
        dttable.Columns.Add(column)

        column = New DataColumn()
        column.DataType = System.Type.GetType("System.Int16")
        column.ColumnName = FieldName.HiddenCCutCode
        column.Caption = FieldName.HiddenCCutCode
        dttable.Columns.Add(column)

        Select Case CInt(_selectedValue)
            Case enumViews.DEFAULT_LIST
                sColumns = Views.DEFAULT_LIST.Split(",")
            Case enumViews.BU_NATURE_OF_RECORD
                sColumns = Views.BU_NATURE_OF_RECORD.Split(",")
            Case enumViews.DIRECTORATE_PROJECTS
                sColumns = Views.DIRECTORATE_PROJECTS.Split(",")
            Case enumViews.MY_RECORDS
                sColumns = Views.MY_RECORDS.Split(",")
            Case enumViews.PROJECTS
                sColumns = Views.PROJECTS.Split(",")
            Case enumViews.RED_RECORDS
                sColumns = Views.RED_RECORDS.Split(",")
            Case enumViews.RECORDS_BY_BUS_PROCESS
                sColumns = Views.RECORDS_BY_BUS_PROCESS.Split(",")
            Case enumViews.RECORDS_BY_CATEGORY
                sColumns = Views.RECORDS_BY_CATEGORY.Split(",")
            Case enumViews.RECORDS_BY_NATURE
                sColumns = Views.RECORDS_BY_NATURE.Split(",")
            Case enumViews.RECORDS_BY_TYPE
                sColumns = Views.RECORDS_BY_TYPE.Split(",")
        End Select

        For j = 0 To sColumns.Count - 1
            Select Case sColumns(j)
                Case FieldName.Alert
                    column = New DataColumn()
                    column.DataType = System.Type.GetType("System.Int16")
                    column.ColumnName = FieldName.Alert
                    column.Caption = FieldName.Alert
                    dttable.Columns.Add(column)
                Case FieldName.Completed
                    column = New DataColumn()
                    column.DataType = System.Type.GetType("System.Boolean")
                    column.ColumnName = FieldName.Completed
                    column.Caption = FieldName.Completed
                    dttable.Columns.Add(column)
                Case FieldName.Ref
                    column = New DataColumn()
                    column.DataType = System.Type.GetType("System.String")
                    column.ColumnName = FieldName.Ref
                    column.Caption = FieldName.Ref
                    dttable.Columns.Add(column)
                Case FieldName.Details
                    column = New DataColumn()
                    column.DataType = System.Type.GetType("System.String")
                    column.ColumnName = FieldName.Details
                    column.Caption = FieldName.Details
                    dttable.Columns.Add(column)
                Case FieldName.Status
                    column = New DataColumn()
                    column.DataType = System.Type.GetType("System.String")
                    column.ColumnName = FieldName.Status
                    column.Caption = FieldName.Status
                    dttable.Columns.Add(column)
                Case FieldName.CostToDate
                    column = New DataColumn()
                    column.DataType = System.Type.GetType("System.Decimal")
                    column.ColumnName = FieldName.CostToDate
                    column.Caption = FieldName.CostToDate
                    dttable.Columns.Add(column)
                Case FieldName.EstimatedCost
                    column = New DataColumn()
                    column.DataType = System.Type.GetType("System.Decimal")
                    column.ColumnName = FieldName.EstimatedCost
                    column.Caption = FieldName.EstimatedCost
                    dttable.Columns.Add(column)
                Case FieldName.CurrentProfile
                    column = New DataColumn()
                    column.DataType = System.Type.GetType("System.String")
                    column.ColumnName = FieldName.CurrentProfile
                    column.Caption = FieldName.CurrentProfile
                    dttable.Columns.Add(column)
                Case FieldName.CurrentRating
                    column = New DataColumn()
                    column.DataType = System.Type.GetType("System.Int16")
                    column.ColumnName = FieldName.CurrentRating
                    column.Caption = FieldName.CurrentRating
                    dttable.Columns.Add(column)
                Case FieldName.ControlledProfile
                    column = New DataColumn()
                    column.DataType = System.Type.GetType("System.String")
                    column.ColumnName = FieldName.ControlledProfile
                    column.Caption = FieldName.ControlledProfile
                    dttable.Columns.Add(column)
                Case FieldName.ControlledRating
                    column = New DataColumn()
                    column.DataType = System.Type.GetType("System.Int16")
                    column.ColumnName = FieldName.ControlledRating
                    column.Caption = FieldName.ControlledRating
                    dttable.Columns.Add(column)
                Case FieldName.AssignedTo
                    column = New DataColumn()
                    column.DataType = System.Type.GetType("System.String")
                    column.ColumnName = FieldName.AssignedTo
                    column.Caption = FieldName.AssignedTo
                    dttable.Columns.Add(column)
                Case FieldName.Category
                    column = New DataColumn()
                    column.DataType = System.Type.GetType("System.String")
                    column.ColumnName = FieldName.Category
                    column.Caption = FieldName.Category
                    dttable.Columns.Add(column)
                Case FieldName.RevPeriod
                    column = New DataColumn()
                    column.DataType = System.Type.GetType("System.Byte")
                    column.ColumnName = FieldName.RevPeriod
                    column.Caption = FieldName.RevPeriod
                    dttable.Columns.Add(column)
                Case FieldName.BusUnit
                    column = New DataColumn()
                    column.DataType = System.Type.GetType("System.String")
                    column.ColumnName = FieldName.BusUnit
                    column.Caption = FieldName.BusUnit
                    dttable.Columns.Add(column)
                Case FieldName.NatureofRecord
                    column = New DataColumn()
                    column.DataType = System.Type.GetType("System.String")
                    column.ColumnName = FieldName.NatureofRecord
                    column.Caption = FieldName.NatureofRecord
                    dttable.Columns.Add(column)
                Case FieldName.UncontrolledProfile
                    column = New DataColumn()
                    column.DataType = System.Type.GetType("System.String")
                    column.ColumnName = FieldName.UncontrolledProfile
                    column.Caption = FieldName.UncontrolledProfile
                    dttable.Columns.Add(column)
                Case FieldName.UncontrolledRating
                    column = New DataColumn()
                    column.DataType = System.Type.GetType("System.Int16")
                    column.ColumnName = FieldName.UncontrolledRating
                    column.Caption = FieldName.UncontrolledRating
                    dttable.Columns.Add(column)
                Case Else
                    column = New DataColumn()
                    column.DataType = System.Type.GetType("System.String")
                    column.ColumnName = "Hidden " & sColumns(j)
                    column.Caption = "Hidden " & sColumns(j)
                    dttable.Columns.Add(column)
            End Select
        Next
    End Sub
#End Region
End Class
