﻿Imports System.Data
Imports System.Globalization
Imports System.Runtime.Serialization

<Serializable()> _
Public MustInherit Class BaseObject
    Implements IDisposable
    Implements ISerializable

#Region " Declarations "
    Private Const PROP_ISDIRTY As String = "IsDirty"
    Private _isDirty As Boolean
    Private _isInitializing As Boolean
#End Region

#Region " Constructors "
    Protected Sub New()
        MyBase.New()
    End Sub

    Protected Sub New(ByVal info As SerializationInfo, ByVal context As StreamingContext)
        MyBase.New()

        If IsNothing(info) Then
            Throw New ArgumentNullException("info")
        End If
        If IsNothing(context) Then
            Throw New ArgumentNullException("context")
        End If

        _isDirty = info.GetBoolean(PROP_ISDIRTY)

    End Sub
#End Region

#Region " Properties "
    Public Property IsDirty() As Boolean
        Get
            Return _isDirty
        End Get
        Set(ByVal New_IsDirty As Boolean)
            If (_isInitializing) Then
                Return
            End If
            _isDirty = New_IsDirty
        End Set
    End Property

    Public Property IsInitializing() As Boolean
        Get
            Return _isInitializing
        End Get
        Set(ByVal New_IsInitializing As Boolean)
            _isInitializing = New_IsInitializing
        End Set
    End Property
#End Region

#Region " Methods "
    Protected Overridable Overloads Sub Dispose(ByVal fDisposing As Boolean)
        If (fDisposing) Then
            ' Free other state (managed objects).
        End If
        ' Free your own state (unmanaged objects).
        ' Set large fields to null.
    End Sub
#End Region

#Region " Overrides "
    Protected Overrides Sub Finalize()
        Dispose(False)
        MyBase.Finalize()
    End Sub
#End Region

#Region " IDisposable Implementation "
    Public Overloads Sub Dispose() Implements System.IDisposable.Dispose
        Dispose(True)
        GC.SuppressFinalize(Me)
    End Sub
#End Region

#Region " ISerializable Implementation "
    Public Overridable Sub GetObjectData(ByVal info As System.Runtime.Serialization.SerializationInfo, ByVal context As System.Runtime.Serialization.StreamingContext) Implements System.Runtime.Serialization.ISerializable.GetObjectData

        If IsNothing(info) Then
            Throw New ArgumentNullException("info")
        End If
        If IsNothing(context) Then
            Throw New ArgumentNullException("context")
        End If

        ' Add class variables
        info.AddValue(PROP_ISDIRTY, _isDirty)

    End Sub
#End Region
End Class
