﻿Imports System
Imports System.Collections
Imports System.Collections.Specialized
Imports System.ComponentModel
Imports System.Globalization

Imports Infragistics.Web.UI.GridControls

Imports Data.Tsql

<Serializable()> _
Public Class FieldCollection
    Inherits System.Collections.Specialized.StringCollection

#Region " Public Constructors "
    ''' <summary>
    ''' Creates a <c>FieldCollection</c> object.
    ''' </summary>
    Public Sub New()
        MyBase.New()
    End Sub

    ''' <summary>
    ''' Creates a <c>FieldCollection</c> object from a list of field names. 
    ''' </summary>
    Public Sub New(ByVal strFieldNames As String)
        MyBase.new()
        Me.Add(strFieldNames, ","c)
    End Sub

    ''' <summary>
    ''' Creates a <c>FieldCollection</c> object from a list of field names. 
    ''' </summary>
    Public Sub New(ByVal strFieldNames As String, ByVal chrDelimiter As Char)
        MyBase.New()
        Me.Add(strFieldNames, chrDelimiter)
    End Sub

    ''' <summary>
    ''' Initializes a new instance of the hierarchical grid <see cref="FieldCollection" /> class from a collection of columns.
    ''' </summary>
    ''' <param name="columns">The columns.</param>
    Public Sub New(ByVal columns As GridFieldCollection)
        MyBase.new()
        For Each column As GridRecordItem In columns
            If Not (column.Column.Hidden) Then
                Me.Add(column.Column.Key)
            End If
        Next
    End Sub
#End Region

#Region " Public Methods "
    Public Shadows Sub Add(ByVal strFieldNames As String)
        Add(strFieldNames, ","c)
    End Sub

    Public Shadows Sub Add(ByVal strFieldNames As String, ByVal chrDelimiter As Char)

        If IsNothing(strFieldNames) Then
            Throw New ArgumentNullException("strFieldNames")
        End If

        Dim aFieldNames() As String = strFieldNames.Split(chrDelimiter)

        ' Trim field names
        Dim nItem As Integer
        For nItem = 0 To UBound(aFieldNames)
            aFieldNames(nItem) = aFieldNames(nItem).Trim
        Next nItem

        ' Add the fields to the collection
        Me.AddRange(aFieldNames)

    End Sub

    Public Sub Parse(ByVal strFieldNames As String)
        MyBase.Clear()
        Me.Add(strFieldNames, ","c)
    End Sub

    Public Sub Parse(ByVal strFieldNames As String, ByVal chrDelimiter As Char)
        MyBase.Clear()
        Me.Add(strFieldNames, chrDelimiter)
    End Sub

    Public Overloads Overrides Function ToString() As String
        Return ToString(","c)
    End Function

    Public Overloads Function ToString(ByVal chrDelimiter As Char) As String

        Dim strOutput As String = ""
        Dim nField As Integer

        For nField = 0 To Me.Count - 1
            If (nField > 0) Then
                strOutput = String.Concat(strOutput, chrDelimiter)
            End If
            strOutput = String.Concat(strOutput, Me.Item(nField))
        Next
        Return strOutput
    End Function

    Public Overloads Function ToSql() As String
        Return Me.ToSql(","c, """"c, """"c)
    End Function

    Public Overloads Function ToSql(ByVal strPrefix As String) As String
        Return Me.ToSql(strPrefix, ","c, """"c, """"c)
    End Function

    Public Overloads Function ToSql(ByVal chrDelimiter As Char, ByVal chrOpenQuote As Char, ByVal chrCloseQuote As Char) As String
        Dim strOutput As String = ""
        Dim nField As Integer

        For nField = 0 To Me.Count - 1
            If (nField > 0) Then
                strOutput = String.Concat(strOutput, chrDelimiter)
            End If
            strOutput = String.Concat(strOutput, chrOpenQuote, Me.Item(nField), chrCloseQuote)
        Next
        Return strOutput
    End Function

    Public Overloads Function ToSql(ByVal strPrefix As String, ByVal chrDelimiter As Char, ByVal chrOpenQuote As Char, ByVal chrCloseQuote As Char) As String
        Dim strOutput As String = ""
        Dim nField As Integer

        For nField = 0 To Me.Count - 1
            If (nField > 0) Then
                strOutput = String.Concat(strOutput, chrDelimiter)
            End If
            strOutput = String.Concat(strOutput, chrOpenQuote, strPrefix, Me.Item(nField), chrCloseQuote)
        Next
        Return strOutput
    End Function

    Public Overloads Function ToSqlAliasString(ByVal strAliasPrefix As String) As String
        Return ToSqlAliasString(Keyword.FieldDelimiter, Keyword.OpenQuote, Keyword.CloseQuote, strAliasPrefix)
    End Function

    Public Overloads Function ToSqlAliasString(ByVal chrDelimiter As Char, ByVal chrOpenQuote As Char, ByVal chrCloseQuote As Char, ByVal strAliasPrefix As String) As String
        Dim strOutput As String = ""
        Dim nField As Integer

        For nField = 0 To Me.Count - 1
            If (nField > 0) Then
                strOutput = String.Concat(strOutput, chrDelimiter)
            End If

            Dim strField As String = String.Format("{0}{2}{1}{3}{0}{4}{2}{1}", chrOpenQuote, chrCloseQuote, Item(nField), Keyword.As, strAliasPrefix)
            strOutput = String.Concat(strOutput, strField)
        Next
        Return strOutput
    End Function
#End Region

End Class

