﻿Imports Data
Imports Data.Tsql
Imports System.ComponentModel
Imports System.Data.Odbc
Imports System.Globalization

<Serializable()> _
Public Class GroupBy

#Region " Fields "
    Private _columnName As String
    Private _selectFields As FieldCollection
    Private _sortIndicator As SortIndicator
    Private _textFormat As String = "[ColumnName]: [Value] (Items: [Count])"
#End Region

#Region " Constructors "
    Public Sub New()
        ColumnName = String.Empty
        SortIndicator = SortIndicator.None
    End Sub

    Public Sub New(ByVal strGroupBy As String)
        If IsNothing(strGroupBy) Then
            Throw New ArgumentNullException("strGroupBy")
        End If

        If (strGroupBy.EndsWith(" (ascending)")) Then
            Me._columnName = Field.GetFieldName(strGroupBy.Substring(0, strGroupBy.Length - 12))
            Me._sortIndicator = SortIndicator.Ascending
        ElseIf (strGroupBy.EndsWith(" ASC")) Then
            Me._columnName = Field.GetFieldName(strGroupBy.Substring(0, strGroupBy.Length - 4))
            Me._sortIndicator = SortIndicator.Ascending
        ElseIf (strGroupBy.EndsWith(" ASCENDING")) Then
            Me._columnName = Field.GetFieldName(strGroupBy.Substring(0, strGroupBy.Length - 10))
            Me._sortIndicator = SortIndicator.Ascending
        ElseIf (strGroupBy.EndsWith(" (descending)")) Then
            Me._columnName = Field.GetFieldName(strGroupBy.Substring(0, strGroupBy.Length - 13))
            Me._sortIndicator = SortIndicator.Descending
        ElseIf (strGroupBy.EndsWith(" DESC")) Then
            Me._columnName = Field.GetFieldName(strGroupBy.Substring(0, strGroupBy.Length - 5))
            Me._sortIndicator = SortIndicator.Descending
        ElseIf (strGroupBy.EndsWith(" DESCENDING")) Then
            Me._columnName = Field.GetFieldName(strGroupBy.Substring(0, strGroupBy.Length - 11))
            Me._sortIndicator = SortIndicator.Descending
        Else
            Me._columnName = Field.GetFieldName(strGroupBy)
            Me._sortIndicator = SortIndicator.Ascending
        End If

    End Sub

    Public Sub New(ByVal strColumnName As String, ByVal fSortIndicator As SortIndicator)
        MyBase.New()
        ' Get the unquoted column name
        Me._columnName = strColumnName
        Me._sortIndicator = fSortIndicator
    End Sub

    Public Sub New(ByVal igcColumn As Infragistics.Web.UI.GridControls.SortedColumnInfo)
        MyBase.New()

        If IsNothing(igcColumn) Then
            Throw New ArgumentNullException("igcColumn")
        End If

        ColumnName = igcColumn.ColumnKey
        SortIndicator = CType(igcColumn.SortDirection, Tsql.SortIndicator)
    End Sub
#End Region

#Region " Properties "
    Public Property ColumnName() As String
        Get
            Return _columnName
        End Get
        Set(ByVal New_ColumnName As String)
            If IsNothing(New_ColumnName) Then
                Throw New ArgumentNullException("New_ColumnName")
            End If
            _columnName = Field.GetFieldName(New_ColumnName.Trim())
        End Set
    End Property

    Public ReadOnly Property SelectFields() As FieldCollection
        Get
            If (Me._selectFields Is Nothing) Then
                Me._selectFields = New FieldCollection()
            End If
            Return Me._selectFields
        End Get
    End Property

    <DefaultValue(SortIndicator.None)> _
    Public Property SortIndicator() As SortIndicator
        Get
            Return _sortIndicator
        End Get
        Set(ByVal New_SortIndicator As SortIndicator)
            _sortIndicator = New_SortIndicator
        End Set
    End Property

    Public Property TextFormat() As String
        Get
            Return Me._textFormat
        End Get
        Set(ByVal value As String)
            Me._textFormat = value
        End Set
    End Property
#End Region

#Region "Methods"
    Public Sub FromSql(ByVal strGroupBy As String)
        If IsNothing(strGroupBy) Then
            Throw New ArgumentNullException("strGroupBy")
        End If

        Dim nChar As Integer = strGroupBy.LastIndexOf(" "c)
        If (nChar = -1) Then
            Throw New ArgumentException("Invalid GroupBy String")
        End If

        ' Get the unquoted column name
        ColumnName = Left$(strGroupBy, nChar)

        If (Mid$(strGroupBy, nChar + 1, Len(strGroupBy) - nChar).Equals(Keyword.Asc)) Then
            SortIndicator = SortIndicator.Ascending
        Else
            SortIndicator = SortIndicator.Descending
        End If
    End Sub

    Public Overrides Function ToString() As String
        If (ColumnName.Length = 0) Then
            Return String.Empty
        End If

        If (SortIndicator = SortIndicator.None) Then
            Return String.Empty
        End If

        Return String.Format("{0} ({1})", ColumnName, SortIndicator.ToString().ToLower())

    End Function

    Public Overridable Function ToSql() As String

        If (ColumnName.Length = 0) Then
            Return String.Empty
        End If

        If (SortIndicator = SortIndicator.None) Then
            Return String.Empty
        End If

        Return String.Format("{0}{1}", Field.GetQuotedFieldName(ColumnName), IIf(SortIndicator.Equals(SortIndicator.Ascending), Keyword.Asc, Keyword.Desc))

    End Function
#End Region

End Class
