﻿Imports Data
Imports Data.Tsql
Imports System.ComponentModel
Imports System.Data.Odbc
Imports System.Globalization

<Serializable()> _
Public Class OrderBy

#Region "Declarations"
    Private _columnName As String
    Private _sortIndicator As SortIndicator
#End Region

#Region "Constructors"
    ''' <summary>
    ''' Creates a new <c>SortCriteria</c> object.
    ''' </summary>
    Public Sub New()
        ColumnName = String.Empty
        SortIndicator = SortIndicator.None
    End Sub

    ''' <summary>
    ''' Creates a new <c>SortCriteria</c> object from a sort criteria string.
    ''' </summary>
    Public Sub New(ByVal strSortCriteria As String)
        If IsNothing(strSortCriteria) Then
            Throw New ArgumentNullException("strSortCriteria")
        End If

        If (strSortCriteria.EndsWith(" (ascending)", StringComparison.CurrentCultureIgnoreCase)) Then
            Me._columnName = Field.GetFieldName(strSortCriteria.Substring(0, strSortCriteria.Length - 12))
            Me._sortIndicator = SortIndicator.Ascending
        ElseIf (strSortCriteria.EndsWith(" ASC", StringComparison.CurrentCultureIgnoreCase)) Then
            Me._columnName = Field.GetFieldName(strSortCriteria.Substring(0, strSortCriteria.Length - 4))
            Me._sortIndicator = SortIndicator.Ascending
        ElseIf (strSortCriteria.EndsWith(" ASCENDING", StringComparison.CurrentCultureIgnoreCase)) Then
            Me._columnName = Field.GetFieldName(strSortCriteria.Substring(0, strSortCriteria.Length - 10))
            Me._sortIndicator = SortIndicator.Ascending
        ElseIf (strSortCriteria.EndsWith(" (descending)", StringComparison.CurrentCultureIgnoreCase)) Then
            Me._columnName = Field.GetFieldName(strSortCriteria.Substring(0, strSortCriteria.Length - 13))
            Me._sortIndicator = SortIndicator.Descending
        ElseIf (strSortCriteria.EndsWith(" DESC", StringComparison.CurrentCultureIgnoreCase)) Then
            Me._columnName = Field.GetFieldName(strSortCriteria.Substring(0, strSortCriteria.Length - 5))
            Me._sortIndicator = SortIndicator.Descending
        ElseIf (strSortCriteria.EndsWith(" DESCENDING", StringComparison.CurrentCultureIgnoreCase)) Then
            Me._columnName = Field.GetFieldName(strSortCriteria.Substring(0, strSortCriteria.Length - 11))
            Me._sortIndicator = SortIndicator.Descending
        Else
            Me._columnName = Field.GetFieldName(strSortCriteria)
            Me._sortIndicator = SortIndicator.Ascending
        End If
    End Sub

    ''' <summary>
    ''' Creates a new <c>SortCriteria</c> object from a field name and sort 
    ''' direction.
    ''' </summary>
    Public Sub New(ByVal strColumnName As String, ByVal fSortIndicator As SortIndicator)
        MyBase.New()
        ' Get the unquoted column name
        ColumnName = strColumnName
        SortIndicator = fSortIndicator
    End Sub

    ''' <summary>
    ''' Creates a new <c>SortCriteria</c> collection from an <c>UltraGridColumn</c>
    ''' object.
    ''' </summary>
    Public Sub New(ByVal igcColumn As Infragistics.Web.UI.GridControls.SortedColumnInfo)
        MyBase.New()

        If IsNothing(igcColumn) Then
            Throw New ArgumentNullException("igcColumn")
        End If

        ColumnName = igcColumn.ColumnKey
        SortIndicator = CType(igcColumn.SortDirection, Tsql.SortIndicator)
    End Sub
#End Region

#Region "Properties"
    ''' <summary>
    ''' Gets or sets the name of the sort column/field in a <c>SortCriteria</c>
    ''' object.
    ''' </summary>
    Public Property ColumnName() As String
        Get
            Return _columnName
        End Get
        Set(ByVal New_ColumnName As String)
            If IsNothing(New_ColumnName) Then
                Throw New ArgumentNullException("New_ColumnName")
            End If
            _columnName = Field.GetFieldName(New_ColumnName.Trim())
        End Set
    End Property

    ''' <summary>
    ''' Gets or sets a value indicating the sort direction of a <c>SortCriteria</c>
    ''' object's column/field.
    ''' </summary>
    <DefaultValue(SortIndicator.None)> _
    Public Property SortIndicator() As SortIndicator
        Get
            Return _sortIndicator
        End Get
        Set(ByVal New_SortIndicator As SortIndicator)
            _sortIndicator = New_SortIndicator
        End Set
    End Property
#End Region

#Region "Methods"
    ''' <summary>
    ''' Creates a new <c>SortCriteria</c> object from an SQL sort criteria string.
    ''' </summary>
    Public Sub FromSql(ByVal strSortCriteria As String)
        If IsNothing(strSortCriteria) Then
            Throw New ArgumentNullException("strSortCriteria")
        End If

        Dim nChar As Integer = strSortCriteria.LastIndexOf(" "c)
        If (nChar = -1) Then
            Throw New ArgumentException("Invalid Sort Criteria String")
        End If

        ' Get the unquoted column name
        ColumnName = Left$(strSortCriteria, nChar)

        ' Part of WHDG integration
        ' Tom 2011-10-06
        If (Mid$(strSortCriteria, nChar + 1, Len(strSortCriteria) - nChar).Equals(Keyword.Asc)) Or (CStr(Mid$(strSortCriteria, nChar + 1, Len(strSortCriteria) - nChar)).Trim.Equals(CStr(SortIndicator.Ascending))) Then
            SortIndicator = SortIndicator.Ascending
        Else
            SortIndicator = SortIndicator.Descending
        End If
    End Sub

    ''' <summary>
    ''' Gets a human readable sort criteria string from a <c>SortCriteria</c> object.
    ''' </summary>
    Public Overrides Function ToString() As String
        If (ColumnName.Length = 0) Then
            Return String.Empty
        End If

        If (SortIndicator = SortIndicator.None) Then
            Return String.Empty
        End If

        Return String.Format("{0} ({1})", ColumnName, SortIndicator.ToString().ToLower())

    End Function

    ''' <summary>
    ''' Gets an SQL sort criteria string from a <c>SortCriteria</c> object.
    ''' </summary>
    Public Overridable Function ToSql() As String

        If (ColumnName.Length = 0) Then
            Return String.Empty
        End If

        If (SortIndicator = SortIndicator.None) Then
            Return String.Empty
        End If

        Return String.Format("{0}{1}", Field.GetQuotedFieldName(ColumnName), IIf(SortIndicator.Equals(SortIndicator.Ascending), Keyword.Asc, Keyword.Desc))

    End Function
#End Region

End Class
